@@ -1,11 +1,13 @@
 #' Network meta-analysis with dose-response relationships
 #'
 #' @description
-#' The `netdose` function performs a dose-response network meta-analysis in a frequentist way.
-#' It accepts a dataset with study-level data, constructs a design matrix for the dose-response model,
-#' and computes treatment effects under common and/or random effects models.
-#' The function supports multiple dose-response relationship modeling approaches, including linear,
-#' exponential, quadratic, restricted cubic splines (rcs), and fractional polynomial methods (fp1).
+#' The `netdose` function performs a dose-response network meta-analysis in a
+#' frequentist way. It accepts a dataset with study-level data, constructs a
+#' design matrix for the dose-response model, and computes treatment effects
+#' under the common and random effects models. The function supports multiple
+#' dose-response relationship modelling approaches, including linear,
+#' exponential, quadratic, restricted cubic splines (rcs), and fractional
+#' polynomials (fp1, fp2).
 #'
 #' @param TE Estimate of treatment effect, i.e. difference between
 #'   first and second treatment (e.g. log odds ratio, mean difference,
@@ -14,23 +16,28 @@
 #' @param seTE Standard error of treatment estimate.
 #' @param agent1 Agents corresponding to the first treatment in each comparison.
 #' @param dose1 Doses for the first treatment in each comparison.
-#' @param agent2 Agents corresponding to the second treatment in each comparison.
+#' @param agent2 Agents corresponding to the second treatment in each
+#'   comparison.
 #' @param dose2 Doses for the second treatment in each comparison.
 #' @param studlab An optional - but important! - vector with study labels.
 #' @param data An optional data frame containing the study information.
 #' @param subset An optional vector specifying a subset of studies to
 #'   be used. The default is `NULL`.
-#' @param n1 Numeric. Optional. Sample sizes for the first treatment in each comparison.
-#' @param n2 Numeric. Optional. Sample sizes for the second treatment in each comparison.
-#' @param event1 Numeric. Optional. Number of events for the first treatment in each comparison.
-#' @param event2 Numeric. Optional. Number of events for the second treatment in each comparison.
+#' @param n1 Numeric. Optional. Sample sizes for the first treatment in
+#'   each comparison.
+#' @param n2 Numeric. Optional. Sample sizes for the second treatment in
+#'   each comparison.
+#' @param event1 Numeric. Optional. Number of events for the first treatment
+#'   in each comparison.
+#' @param event2 Numeric. Optional. Number of events for the second treatment
+#'   in each comparison.
 #' @param sm  A character string indicating underlying summary measure,
 #'   e.g., \code{"RD"}, \code{"RR"}, \code{"OR"}, \code{"ASD"},
 #'   \code{"HR"}, \code{"MD"}, \code{"SMD"}, or \code{"ROM"}.
-#' @param common A logical indicating whether a common effects dose-response network
-#'   meta-analysis should be conducted. The default is `TRUE`.
-#' @param random A logical indicating whether a random effects dose-response network
-#'   meta-analysis should be conducted. The default is `TRUE`.
+#' @param common A logical indicating whether a common effects dose-response
+#'   network meta-analysis should be conducted. The default is \code{TRUE}.
+#' @param random A logical indicating whether a random effects dose-response
+#'   network meta-analysis should be conducted. The default is \code{TRUE}.
 #' @param tau.preset An optional value for the square-root of the
 #'   between-study variance \eqn{\tau^2}.
 #' @param method An optional character string specifying the method to
@@ -52,15 +59,14 @@
 #' example.
 #' @param tol.multiarm A numeric for the tolerance for consistency of
 #'   treatment estimates in multi-arm studies which are consistent by
-#'   design.
+#'   design (only considered for standard network meta-analysis model).
 #' @param tol.multiarm.se A numeric for the tolerance for consistency
 #'   of standard errors in multi-arm studies which are consistent by
-#'   design. This check is not conducted if the argument is
-#'   \code{NULL}.
+#'   design (only considered for standard network meta-analysis model).
 #' @param details.chkmultiarm A logical indicating whether treatment
 #'   estimates and / or variances of multi-arm studies with
 #'   inconsistent results or negative multi-arm variances should be
-#'   printed.
+#'   printed (only considered for standard network meta-analysis model).
 #' @param keepdata A logical indicating whether original data(set)
 #'   should be kept in netdose object.
 #' @param warn A logical indicating whether warnings should be printed
@@ -68,13 +74,12 @@
 #'   standard errors).
 #' @param func.inverse R function used to calculate the pseudoinverse
 #'   of the Laplacian matrix L.
-#' @param ... Additional arguments (to catch deprecated arguments).
 #'
 #' @details
 #' The dose-response network meta-analysis (DR-NMA) has been implemented
 #' by modelling different dose-response functions, as described by
 #' Mandema et al. 2005 and Mawdsley et al. 2016 and by using restricted cubic
-#' splines (Hamza et al. 2020) in Bayesian framework.
+#' splines (Hamza et al. 2024) in a Bayesian setting.
 #'
 #' The function \code{netdose} conducts a dose-response network meta-analysis
 #' with a variety of dose-response functions (such as the linear, exponential,
@@ -85,7 +90,8 @@
 #' \itemize{
 #' \item Linear dose-response relationship (\code{method = "linear"})
 #' \item Exponential dose-response relationship (\code{method = "exponential"})
-#' \item Quadratic polynomial dose-response relationship (\code{method = "quadratic"})
+#' \item Quadratic polynomial dose-response relationship
+#'   (\code{method = "quadratic"})
 #' \item Restricted cubic splines (\code{method = "rcs"})
 #' \item Fractional polynomial (order 1) (\code{method = "fp1"})
 #' \item Fractional polynomial (order 2) (\code{method = "fp2"})
@@ -106,8 +112,10 @@
 #' An object of class \code{netdose}; a list containing the
 #' following components:
 #' \item{studlab}{Study labels.}
-#' \item{agent1}{Label/Agents corresponding to the first treatment in each comparison..}
-#' \item{agent2}{Label/Agents corresponding to the second treatment in each comparison..}
+#' \item{agent1}{Label/Agents corresponding to the first treatment in each
+#'   comparison.}
+#' \item{agent2}{Label/Agents corresponding to the second treatment in each
+#'   comparison.}
 #' \item{dose1}{Doses for the first treatment in each comparison.}
 #' \item{dose2}{Doses for the second treatment in each comparison.}
 #' \item{treat1}{Label/First treatment in each comparison.}
@@ -130,7 +138,7 @@
 #'
 #' \item{common.dose}{Common dose value used in the analysis, if specified.}
 #'
-#' #' **Common/Random effects model results:**
+#' **Common/Random effects model results:**
 #'  \item{TE.common, TE.random}{Matrix with overall
 #'   treatment effects estimated by the dose-response (common and random
 #'   effects) model.}
@@ -150,103 +158,107 @@
 #' \item{seTE.drnma.common, seTE.drnma.random}{A vector with corresponding
 #'   standard errors (common and random effects model).}
 #' \item{lower.drnma.common, lower.drnma.random}{A vector with lower
-#'   confidence limits for dose-response treatment estimates (common and random effects
-#'   model).}
+#'   confidence limits for dose-response treatment estimates (common and
+#'   random effects model).}
 #' \item{upper.drnma.common, upper.drnma.random}{A vector with upper
-#'  confidence limits for dose-response treatment estimates (common and random effects
-#'   model).}
+#'  confidence limits for dose-response treatment estimates (common and
+#'  random effects model).}
 #' \item{statistic.drnma.common, statistic.drnma.random}{A vector with
-#'  z-values for the overall dose-response effects (common and random
+#'   z-values for the overall dose-response effects (common and random
 #'   effects model).}
 #' \item{pval.drnma.common, pval.drnma.random}{A vector with p-values for
 #'   the overall dose-response effects (common and random effects
 #'   model).}
 #'
 #' **Heterogeneity and goodness-of-fit statistics:**
-#' \item{Q.dose}{Overall heterogeneity / inconsistency statistic for
-#' dose-response network meta-analysis.}
-#' \item{df.Q.dose}{Degrees of freedom for test of heterogeneity /
+#' \item{Q}{Overall heterogeneity / inconsistency statistic for
+#'   dose-response network meta-analysis.}
+#' \item{df.Q}{Degrees of freedom for test of heterogeneity /
 #'   inconsistency for dose-response network meta-analysis.}
-#' \item{pval.Q.dose}{P-value for test of heterogeneity /
+#' \item{pval.Q}{P-value for test of heterogeneity /
 #'   inconsistency for dose-response network meta-analysis.}
 #' \item{tau}{Square-root of between-study variance with DerSimonian
-#' and Laird method for dose-response network meta-analysis.}
+#'   and Laird method for dose-response network meta-analysis.}
 #' \item{tauml}{Square-root of between-study variance with Maximum
-#'  likelihood method for dose-response network meta-analysis.}
+#'   likelihood method for dose-response network meta-analysis.}
 #' \item{I2, lower.I2, upper.I2}{I-squared, lower and upper confidence
 #'   limits.}
-#' \item{Q.standard}{Overall heterogeneity / inconsistency statistic
-#'   (standard model).}
-#' \item{df.Q.standard}{Degrees of freedom for test of heterogeneity /
-#'   inconsistency (standard model).}
-#' \item{pval.Q.standard}{P-value for test of heterogeneity /
-#'   inconsistency (standard model).}
-#' \item{Q.diff}{Test statistic for difference in goodness of fit
-#'   between standard and dose-response model.}
-#' \item{df.Q.diff}{Degrees of freedom for difference in goodness of
-#'   fit between standard and dose-response model.}
-#' \item{pval.Q.diff}{P-value for difference in goodness of fit
-#'   between standard and additive model.}
+#' \item{Q.lump}{Overall heterogeneity / inconsistency statistic
+#'   (NMA, lumping approach).}
+#' \item{df.Q.lump}{Degrees of freedom for test of heterogeneity /
+#'   inconsistency (NMA, lumping approach).}
+#' \item{pval.Q.lump}{P-value for test of heterogeneity /
+#'   inconsistency (NMA, lumping approach).}
+#' \item{Q.split}{Overall heterogeneity / inconsistency statistic
+#'   (NMA, splitting approach).}
+#' \item{df.Q.split}{Degrees of freedom for test of heterogeneity /
+#'   inconsistency (NMA, splitting approach).}
+#' \item{pval.Q.split}{P-value for test of heterogeneity /
+#'   inconsistency (NMA, splitting approach).}
 #'
-#' \item{Xd}{Design matrix for dose-response network meta-analysis.}
+#' \item{B.matrix}{Edge-vertex incidence matrix.}
+#' \item{D_obs.matrix}{Matrix with observed doses.}
+#' \item{D.matrix}{Matrix with transformed doses.}
+#' \item{X.matrix}{Design matrix for dose-response network meta-analysis.}
 #'
 #' \item{sm}{Summary measure used in the analysis.}
 #' \item{level}{Level used to calculate confidence intervals for
-#'  individual comparisons.}
-#' \item{common}{A logical indicating whether a common effects dose-response network
-#'  meta-analysis should be conducted.}
-#' \item{random}{A logical indicating whether a random effects dose-response network
-#' meta-analysis should be conducted.}
+#'   individual comparisons.}
+#' \item{common}{A logical indicating whether a common effects dose-response
+#'   network meta-analysis should be conducted.}
+#' \item{random}{A logical indicating whether a random effects dose-response
+#'   network meta-analysis should be conducted.}
 #' \item{method}{Method used for the dose-response relationship.}
 #'
 #' \item{reference.group}{Reference agent.}
-#' \item{Q.to.df.ratio}{Q to df ratio, i.e, Q.dose/df.Q.dose.}
+#' \item{Q.to.df.ratio}{Q to df ratio, i.e, Q/df.Q.}
 #' \item{func.inverse}{Function used to calculate the pseudoinverse of
-#' the Laplacian matrix L.}
+#'   the Laplacian matrix L.}
 #' \item{backtransf}{A logical indicating whether results should be
-#' back transformed in printouts and forest plots.}
+#'   back transformed in printouts and forest plots.}
 #'
 #' \item{data}{Data frame containing the study information.}
 #'
-#' @author Maria Petropoulou <maria.petropoulou@uniklinik-freiburg.de>,
-#'   Guido Schwarzer <guido.schwarzer@uniklinik-freiburg.de>
+#' @author Maria Petropoulou <m.petropoulou.a@gmail.com>,
+#'   Guido Schwarzer <guido.schwarzer@@uniklinik-freiburg.de>
 #'
 #' @references
 #' Mandema JW, Cox EJ (2005):
-#' Therapeutic benefit of eletriptan compared to sumatriptan for the acute relief
-#' of migraine pain--results of a model-based meta-analysis that accounts for encapsulation.
+#' Therapeutic benefit of eletriptan compared to sumatriptan for the acute
+#' relief of migraine pain--results of a model-based meta-analysis that accounts
+#' for encapsulation.
 #' \emph{Cephalalgia},
-#' \bold{25}, 715-725
+#' \bold{25}, 715--25
 #'
 #' Mawdsley D, Bennetts M, Dias S, Boucher M, Welton N (2016):
-#' Model-Based Network Meta-Analysis: A Framework for Evidence Synthesis of Clinical Trial Data.
+#' Model-Based Network Meta-Analysis: A Framework for Evidence Synthesis of
+#' Clinical Trial Data.
 #' \emph{PT Pharmacometrics & Systems Pharmacology},
-#' \bold{5}, 393-401
+#' \bold{5}, 393--401
 #'
-#' Hamza T, Furukawa TA, Orsin N, Cipriani A, Iglesias C, Salanti G (2022):
-#' A dose-effect network meta-analysis model: an application in antidepressants.
-#' \emph{Statistical Methods in Medical Research}
+#' Hamza T, Furukawa TA, Orsin N, Cipriani A, Iglesias CP, Salanti G (2024):
+#' A dose-effect network meta-analysis model with application in antidepressants
+#' using restricted cubic splines.
+#' \emph{Statistical Methods in Medical Research},
+#' \bold{33}, 1461--72
 #'
 #' Petropoulou et al. (2025):
 #' Network meta-analysis with dose-response relationships.
 #'
 #' @examples
-#' # Load anesthesia data
-#' data(anesthesia)
-#'
-#' # Use a subset of 5 studies
-#' anesthesia_subset <- subset(anesthesia, study %in% unique(anesthesia$study)[1:5])
+#' # Use a subset of 3 studies from anesthesia data
+#' anesthesia_subset <-
+#'   subset(anesthesia, study %in% unique(anesthesia$study)[1:3])
 #'
 #' # Prepare data for DR-NMA
-#' dat <- meta::pairwise(
+#' dat <- pairwise(
 #'   agent = list(agent1, agent2, agent3),
 #'   event = list(event1, event2, event3),
 #'   n = list(n1, n2, n3),
 #'   dose = list(dose1, dose2, dose3),
 #'   data = anesthesia_subset,
 #'   studlab = study,
-#'   append = FALSE,
-#'   sm = "RR"
+#'   append = FALSE
 #' )
 #'
 #' # Perform DR-NMA with a linear dose-response function
@@ -258,20 +270,19 @@
 #' 
 #' \donttest{
 #' # DR-NMA with FP1 dose-response function with p = -0.5
-#' FP1 <- netdose(TE, seTE, agent1, dose1, agent2,
+#' dr_fp1 <- netdose(TE, seTE, agent1, dose1, agent2,
 #'   dose2, studlab,
 #'   data = dat,
 #'   method = "fp1"
 #' )
 #'
 #' # DR-NMA with FP1 dose-response function with p = 0.5
-#' FP1_p0.5 <- netdose(TE, seTE, agent1, dose1, agent2,
+#' dr_fp1_p0.5 <- netdose(TE, seTE, agent1, dose1, agent2,
 #'   dose2, studlab,
 #'   data = dat,
 #'   method = "fp1", param = 0.5
 #' )
 #'
-#'
 #' # DR-NMA with RCS dose-response function with knots at 10th, 50th and 90th percentiles
 #' dr_rcs <- netdose(TE, seTE, agent1, dose1, agent2,
 #'   dose2, studlab,
@@ -289,8 +300,6 @@
 #'
 #' @export netdose
 
-
-
 netdose <- function(TE, seTE, agent1, dose1, agent2, dose2, studlab,
                     data = NULL, subset = NULL,
                     #
@@ -320,9 +329,7 @@ netdose <- function(TE, seTE, agent1, dose1, agent2, dose2, studlab,
                     #
                     keepdata = gs("keepdata"),
                     #
-                    warn = TRUE,
-                    #
-                    ...) {
+                    warn = TRUE) {
   #
   #
   # (1) Check arguments
@@ -341,13 +348,12 @@ netdose <- function(TE, seTE, agent1, dose1, agent2, dose2, studlab,
       "fp1", "fp2"
     ))
   #
-  if (method == "rcs") {
+  if (method == "rcs")
     chknumeric(param)
-  } else if (method == "fp2") {
+  else if (method == "fp2")
     chknumeric(param, length = 2)
-  } else {
+  else
     chknumeric(param, length = 1)
-  }
   #
   chklevel(level)
   chklogical(backtransf)
@@ -360,14 +366,14 @@ netdose <- function(TE, seTE, agent1, dose1, agent2, dose2, studlab,
   #
   chklogical(keepdata)
   chklogical(warn)
-
-
+  
+  
   #
   #
   # (2) Read data
   #
   #
-
+  
   nulldata <- is.null(data)
   sfsp <- sys.frame(sys.parent())
   mc <- match.call()
@@ -384,18 +390,18 @@ netdose <- function(TE, seTE, agent1, dose1, agent2, dose2, studlab,
     if (missing.reference.group) {
       missing.reference.group.pairwise <- TRUE
       reference.group <- attr(TE, "reference.group")
-      if (is.null(reference.group)) {
+      #
+      if (is.null(reference.group))
         reference.group <- ""
-      } else {
+      else
         missing.reference.group <- FALSE
-      }
     }
     #
     keep.all.comparisons <- attr(TE, "keep.all.comparisons")
     if (!is.null(keep.all.comparisons) && !keep.all.comparisons) {
       stop("First argument is a pairwise object created with ",
-        "'keep.all.comparisons = FALSE'.",
-        call. = TRUE
+           "'keep.all.comparisons = FALSE'.",
+           call. = TRUE
       )
     }
     #
@@ -425,14 +431,14 @@ netdose <- function(TE, seTE, agent1, dose1, agent2, dose2, studlab,
     dose2 <- catch("dose2", mc, data, sfsp)
     #
     TE <- TE$TE
-  } else {
+  }
+  else {
     is.pairwise <- FALSE
     if (missing(sm)) {
-      if (!is.null(data) && !is.null(attr(data, "sm"))) {
+      if (!is.null(data) && !is.null(attr(data, "sm")))
         sm <- attr(data, "sm")
-      } else {
+      else
         sm <- ""
-      }
     }
     #
     seTE <- catch("seTE", mc, data, sfsp)
@@ -457,9 +463,9 @@ netdose <- function(TE, seTE, agent1, dose1, agent2, dose2, studlab,
   #
   if (!any(!is.na(TE) & !is.na(seTE))) {
     stop("Missing data for estimates (argument 'TE') and ",
-      "standard errors (argument 'seTE') in all studies.\n  ",
-      "No network meta-analysis possible.",
-      call. = FALSE
+         "standard errors (argument 'seTE') in all studies.\n  ",
+         "No network meta-analysis possible.",
+         call. = FALSE
     )
   }
   #
@@ -471,18 +477,16 @@ netdose <- function(TE, seTE, agent1, dose1, agent2, dose2, studlab,
   chklength(agent2, k.Comp, "TE")
   chklength(dose2, k.Comp, "TE")
   #
-  if (is.null(studlab)) {
+  if (is.null(studlab))
     studlab <- seq_along(TE)
-  } else {
+  else
     chklength(studlab, k.Comp, "TE")
-  }
   #
-  if (is.factor(agent1)) {
+  if (is.factor(agent1))
     agent1 <- as.character(agent1)
-  }
-  if (is.factor(agent2)) {
+  #
+  if (is.factor(agent2))
     agent2 <- as.character(agent2)
-  }
   #
   # Remove leading and trailing whitespace
   #
@@ -492,8 +496,8 @@ netdose <- function(TE, seTE, agent1, dose1, agent2, dose2, studlab,
   if (length(studlab) == 0) {
     if (warn) {
       warning("No information given for argument 'studlab'. ",
-        "Assuming that comparisons are from independent studies.",
-        call. = FALSE
+              "Assuming that comparisons are from independent studies.",
+              call. = FALSE
       )
     }
     studlab <- seq(along = TE)
@@ -503,22 +507,20 @@ netdose <- function(TE, seTE, agent1, dose1, agent2, dose2, studlab,
   subset <- catch("subset", mc, data, sfsp)
   missing.subset <- is.null(subset)
   #
-  if (!is.null(event1) & !is.null(event2)) {
+  if (!is.null(event1) & !is.null(event2))
     available.events <- TRUE
-  } else {
+  else
     available.events <- FALSE
-  }
   #
-  if (!is.null(n1) & !is.null(n2)) {
+  if (!is.null(n1) & !is.null(n2))
     available.n <- TRUE
-  } else {
+  else
     available.n <- FALSE
-  }
   #
   treat1 <- paste(agent1, dose1)
   treat2 <- paste(agent2, dose2)
-
-
+  
+  
   #
   #
   # (2b) Store complete dataset in list object data
@@ -528,12 +530,13 @@ netdose <- function(TE, seTE, agent1, dose1, agent2, dose2, studlab,
   if (keepdata) {
     if (nulldata & !is.pairwise) {
       data <- data.frame(.studlab = studlab, stringsAsFactors = FALSE)
-    } else if (nulldata & is.pairwise) {
+    }
+    else if (nulldata & is.pairwise) {
       data <- pairdata
       data$.studlab <- studlab
-    } else {
-      data$.studlab <- studlab
     }
+    else
+      data$.studlab <- studlab
     #
     data$.order <- seq_along(studlab)
     #
@@ -588,14 +591,15 @@ netdose <- function(TE, seTE, agent1, dose1, agent2, dose2, studlab,
     if (!missing.subset) {
       if (length(subset) == dim(data)[1]) {
         data$.subset <- subset
-      } else {
+      }
+      else {
         data$.subset <- FALSE
         data$.subset[subset] <- TRUE
       }
     }
   }
-
-
+  
+  
   #
   #
   # (3) Use subset for analysis
@@ -603,9 +607,9 @@ netdose <- function(TE, seTE, agent1, dose1, agent2, dose2, studlab,
   #
   if (!missing.subset) {
     if ((is.logical(subset) & (sum(subset) > k.Comp)) ||
-      (length(subset) > k.Comp)) {
+        (length(subset) > k.Comp)) {
       stop("Length of subset is larger than number of studies.",
-        call. = FALSE
+           call. = FALSE
       )
     }
     #
@@ -644,32 +648,33 @@ netdose <- function(TE, seTE, agent1, dose1, agent2, dose2, studlab,
   #
   if (!is.null(common.dose)) {
     chklength(common.dose, length(agents),
-      text =
-        paste(
-          "Argument 'common.dose' must be a named vector of",
-          "length", length(agents),
-          "(number of agents in network)."
-        )
+              text =
+                paste(
+                  "Argument 'common.dose' must be a named vector of",
+                  "length", length(agents),
+                  "(number of agents in network)."
+                )
     )
     #
     names(common.dose) <- setchar(names(common.dose), agents)
-  } else {
+  }
+  else {
     by_dose <- by(c(dose1, dose2), c(agent1, agent2), median, na.rm = TRUE)
     #
     common.dose <- as.vector(by_dose)
     names(common.dose) <- names(by_dose)
   }
-
-
+  
+  
   #
   #
   # (4) Additional checks
   #
   #
-
+  
   if (any(agent1 == agent2 & dose1 == dose2)) {
     stop("Same combination of agent and dose in at least one comparison.",
-      call. = FALSE
+         call. = FALSE
     )
   }
   #
@@ -694,21 +699,21 @@ netdose <- function(TE, seTE, agent1, dose1, agent2, dose2, studlab,
     )
     if (warn) {
       warning("Comparison",
-        if (sum(excl) > 1) "s",
-        " with missing TE / seTE or zero seTE not considered ",
-        "in network meta-analysis.",
-        call. = FALSE
+              if (sum(excl) > 1) "s",
+              " with missing TE / seTE or zero seTE not considered ",
+              "in network meta-analysis.",
+              call. = FALSE
       )
     }
     if (warn) {
       cat("Comparison",
-        if (sum(excl) > 1) "s",
-        " not considered in network meta-analysis:\n",
-        sep = ""
+          if (sum(excl) > 1) "s",
+          " not considered in network meta-analysis:\n",
+          sep = ""
       )
       prmatrix(dat.NAs,
-        quote = FALSE, right = TRUE,
-        rowlab = rep("", sum(excl))
+               quote = FALSE, right = TRUE,
+               rowlab = rep("", sum(excl))
       )
       cat("\n")
     }
@@ -758,21 +763,21 @@ netdose <- function(TE, seTE, agent1, dose1, agent2, dose2, studlab,
     )
     if (warn) {
       warning("Comparison",
-        if (sum(excl) > 1) "s",
-        " with missing dose information not considered ",
-        "in network meta-analysis.",
-        call. = FALSE
+              if (sum(excl) > 1) "s",
+              " with missing dose information not considered ",
+              "in network meta-analysis.",
+              call. = FALSE
       )
     }
     if (warn) {
       cat("Comparison",
-        if (sum(excl) > 1) "s",
-        " not considered in network meta-analysis:\n",
-        sep = ""
+          if (sum(excl) > 1) "s",
+          " not considered in network meta-analysis:\n",
+          sep = ""
       )
       prmatrix(dat.NAs,
-        quote = FALSE, right = TRUE,
-        rowlab = rep("", sum(excl))
+               quote = FALSE, right = TRUE,
+               rowlab = rep("", sum(excl))
       )
       cat("\n")
     }
@@ -848,10 +853,10 @@ netdose <- function(TE, seTE, agent1, dose1, agent2, dose2, studlab,
   #
   if (n.ai > 0) {
     stop("The following agent",
-      if (n.ai > 1) "s have " else " has ",
-      "doses equal to zero and larger than zero: ",
-      paste0("'", active_and_inactive, "'", collapse = ", "),
-      call. = FALSE
+         if (n.ai > 1) "s have " else " has ",
+         "doses equal to zero and larger than zero: ",
+         paste0("'", active_and_inactive, "'", collapse = ", "),
+         call. = FALSE
     )
   }
   #
@@ -862,18 +867,20 @@ netdose <- function(TE, seTE, agent1, dose1, agent2, dose2, studlab,
   if (missing.reference.group | missing.reference.group.pairwise) {
     if (length(inactive) > 0) {
       reference.group <- inactive[1]
-    } else {
+    }
+    else {
       go.on <- TRUE
       i <- 0
       while (go.on) {
         i <- i + 1
         sel.i <-
           !is.na(TE) & !is.na(seTE) &
-            (agent1 == labels[i] | agent2 == labels[i])
+          (agent1 == labels[i] | agent2 == labels[i])
         if (sum(sel.i) > 0) {
           go.on <- FALSE
           reference.group <- labels[i]
-        } else if (i == length(labels)) {
+        }
+        else if (i == length(labels)) {
           go.on <- FALSE
           reference.group <- ""
         }
@@ -884,45 +891,50 @@ netdose <- function(TE, seTE, agent1, dose1, agent2, dose2, studlab,
   if (reference.group != "") {
     reference.group <- setref(reference.group, labels)
   }
-
-
+  
+  
   #
   #
-  # (5) Create design matrix Xd.matrix
+  # (5) Create design matrix X
   #
   #
-
+  
   if (method == "linear") {
     param <- NULL
     #
     M <- createXd1(agent1, dose1, agent2, dose2, studlab, g = dose2dose)
-  } else if (method == "exponential") {
+  }
+  else if (method == "exponential") {
     param <- NULL
     #
     M <- createXd1(agent1, dose1, agent2, dose2, studlab, g = dose2exp)
-  } else if (method == "fp1") { # fractional polynomial (order 1)
+  }
+  else if (method == "fp1") { # fractional polynomial (order 1)
     if (is.null(param)) {
       param <- -0.5
     }
     #
     M <- createXd1(agent1, dose1, agent2, dose2, studlab,
-      g = dose2fp, param = param
+                   g = dose2fp, param = param
     )
-  } else if (method == "quadratic") { # quadratic polynomial
+  }
+  else if (method == "quadratic") { # quadratic polynomial
     param <- NULL
     #
     M <- createXd2(agent1, dose1, agent2, dose2, studlab,
-      g1 = dose2dose, g2 = dose2poly, param = param
+                   g1 = dose2dose, g2 = dose2poly, param = param
     )
-  } else if (method == "fp2") { # fractional polynomial (order 2)
+  }
+  else if (method == "fp2") { # fractional polynomial (order 2)
     if (is.null(param)) {
       param <- c(-0.5, 1)
     }
     #
     M <- createXd2(agent1, dose1, agent2, dose2, studlab,
-      g1 = dose2fp, g2 = dose2fp, param = param
+                   g1 = dose2fp, g2 = dose2fp, param = param
     )
-  } else if (method == "rcs") { # restricted cubic splines
+  }
+  else if (method == "rcs") { # restricted cubic splines
     if (is.null(param)) { # Harrell's suggestion (fixed sample quantiles)
       param <- c(0.10, 0.50, 0.90)
     }
@@ -931,83 +943,97 @@ netdose <- function(TE, seTE, agent1, dose1, agent2, dose2, studlab,
     M <- createXd_rcs(agent1, dose1, agent2, dose2, studlab, param = param)
   }
   #
-  Xd <- M$Xd
-  D.matrix <- M$D
-
-
+  B.matrix <- M$B.matrix
+  D_obs.matrix <- M$D_obs.matrix
+  D.matrix <- M$D.matrix
+  X.matrix <- M$X.matrix
+  
+  
   #
   #
   # (6) Conduct DR-NMA
   #
   #
-
+  
   p0 <- prepare(TE, seTE, treat1, treat2, studlab, func.inverse = func.inverse)
-
   ps <- prepare(TE, seTE, agent1, agent2, studlab, func.inverse = func.inverse)
   #
   o <- order(p0$order)
   os <- order(ps$order)
+  
   #
-  # Standard network meta-analysis (to calculate Q statistic)
-
-  same_elements <- agent1 == agent2
-
-  if (any(same_elements == TRUE)) {
-    Q <- df.Q <- pval.Q <- df.Q.diff <- NA
-  }else{
+  # Standard network meta-analysis
   #
-  if (netconnection(agent1, agent2, ps$studlab[os])$n.subnets == 1) {
-    net <- netmeta(ps$TE[os], ps$seTE[os], agent1, agent2, ps$studlab[os],
-      reference.group = reference.group,
-      tol.multiarm = tol.multiarm,
-      tol.multiarm.se = tol.multiarm.se,
-      details.chkmultiarm = details.chkmultiarm
-    )
+  same_agents <- agent1 == agent2
+  #
+  Q.lump <- df.Q.lump <- pval.Q.lump <- NA
+  #
+  Q.split <- df.Q.split <- pval.Q.split <- NA
+  #
+  if (!any(same_agents)) {
     #
-    Q <- net$Q
-    df.Q <- net$df.Q
-    pval.Q <- net$pval.Q
+    # Lumping approach
     #
-    df.Q.diff <- 2 * sum(1 / ps$narms[os]) - qr(Xd)$rank
-  } else {
-    Q <- df.Q <- pval.Q <- df.Q.diff <- NA
-  }
+    if (netconnection(agent1, agent2, ps$studlab[os])$n.subnets == 1) {
+      net1 <- netmeta(ps$TE[os], ps$seTE[os], agent1, agent2, ps$studlab[os],
+                      reference.group = reference.group,
+                      tol.multiarm = tol.multiarm,
+                      tol.multiarm.se = tol.multiarm.se,
+                      details.chkmultiarm = details.chkmultiarm
+      )
+      #
+      Q.lump <- net1$Q
+      df.Q.lump <- net1$df.Q
+      pval.Q.lump <- net1$pval.Q
+    }
+    #
+    # Splitting approach
+    #
+    if (netconnection(treat1, treat2, ps$studlab[os])$n.subnets == 1) {
+      net2 <- netmeta(ps$TE[os], ps$seTE[os], treat1, treat2, ps$studlab[os],
+                      reference.group = reference.group,
+                      tol.multiarm = tol.multiarm,
+                      tol.multiarm.se = tol.multiarm.se,
+                      details.chkmultiarm = details.chkmultiarm
+      )
+      #
+      Q.split <- net2$Q
+      df.Q.split <- net2$df.Q
+      pval.Q.split <- net2$pval.Q
+    }
   }
+  
+  
   #
   # Common effects DR-NMA model
   #
   res.c <- nma_dose(p0$TE[o], p0$seTE[o], p0$weights[o], p0$studlab[o],
-    agent1, agent2, p0$treat1[o], p0$treat2[o],
-    p0$narms[o],
-    Xd = Xd, D.matrix = D.matrix, n = n,
-    Q = Q, df.Q.diff = df.Q.diff,
-    level = level, reference = reference.group
+                    agent1, agent2, p0$treat1[o], p0$treat2[o],
+                    p0$narms[o],
+                    Xd = X.matrix, D = D.matrix, n = n,
+                    level = level, reference = reference.group
   )
   #
   # Random effects DR-NMA model
   #
   tau <- res.c$tau
   #
-  p1 <- prepare(
-    TE, seTE, treat1, treat2, studlab,
-    if (is.na(tau)) 0 else tau, invmat
-  )
+  p1 <- prepare(TE, seTE, treat1, treat2, studlab,
+                if (is.na(tau)) 0 else tau, invmat)
   #
   res.r <- nma_dose(p1$TE[o], p1$seTE[o], p1$weights[o], p1$studlab[o],
-    agent1, agent2, p1$treat1[o], p1$treat2[o],
-    p1$narms[o],
-    Xd = Xd, D.matrix = D.matrix, n = n,
-    Q = NA, df.Q.diff = NA,
-    level = level, reference = reference.group
-  )
-
-
+                    agent1, agent2, p1$treat1[o], p1$treat2[o],
+                    p1$narms[o],
+                    Xd = X.matrix, D = D.matrix, n = n,
+                    level = level, reference = reference.group)
+  
+  
   #
   #
   # (6) Generate DR-NMA object
   #
   #
-
+  
   res <- list(
     studlab = studlab,
     agent1 = agent1,
@@ -1067,22 +1093,27 @@ netdose <- function(TE, seTE, agent1, dose1, agent2, dose2, studlab,
     statistic.drnma.random = res.r$statistic.nma,
     pval.drnma.random = res.r$pval.nma,
     #
-    Q.dose = res.c$Q.dose,
-    df.Q.dose = res.c$df.Q.dose,
-    pval.Q.dose = res.c$pval.Q.dose,
+    Q = res.c$Q,
+    df.Q = res.c$df.Q,
+    pval.Q = res.c$pval.Q,
+    Q.to.df.ratio = res.c$H^2,
+    #
     tau = res.c$tau,
     tauml = res.c$tauML,
     I2 = res.c$I2, lower.I2 = res.c$lower.I2, upper.I2 = res.c$upper.I2,
     #
-    Q.standard = Q,
-    df.Q.standard = df.Q,
-    pval.Q.standard = pval.Q,
+    Q.lump = Q.lump,
+    df.Q.lump = df.Q.lump,
+    pval.Q.lump = pval.Q.lump,
     #
-    Q.diff = res.c$Q.diff,
-    df.Q.diff = df.Q.diff,
-    pval.Q.diff = res.c$pval.Q.diff,
+    Q.split = Q.split,
+    df.Q.split = df.Q.split,
+    pval.Q.split = pval.Q.split,
     #
-    Xd = Xd,
+    B.matrix = B.matrix,
+    D_obs.matrix = D_obs.matrix,
+    D.matrix = D.matrix,
+    X.matrix = X.matrix,
     #
     sm = sm,
     level = level,
@@ -1091,10 +1122,10 @@ netdose <- function(TE, seTE, agent1, dose1, agent2, dose2, studlab,
     method = method,
     #
     param = param,
+    knots = if (method == "rcs") attr(X.matrix, "param"),
     #
     reference.group = reference.group,
     #
-    Q.to.df.ratio = res.c$Q.df,
     func.inverse = deparse(substitute(func.inverse)),
     #
     backtransf = backtransf,
